@@ -144,18 +144,6 @@ class Impl : public Itf, public mhw::Impl
     MmioRegistersVdbox m_mmioRegisters[MHW_VDBOX_NODE_MAX] = {};  //!< Mfx mmio registers
 
 public:
-    virtual uint32_t GetCmd1CommandSize() override
-    {
-        // Just return 0 here, please implement logic in platform sepecific impl class.
-        return 0;
-    }
-
-    virtual uint32_t GetCmd2CommandSize() override
-    {
-        // Just return 0 here, please implement logic in platform sepecific impl class.
-        return 0;
-    }
-
     MOS_STATUS SetRowstoreCachingOffsets(const RowStorePar &par) override
     {
         MHW_FUNCTION_ENTER;
